@@ -1,82 +1,33 @@
 package Catalyst::View::JavaScript::Minifier::XS;
+our $VERSION = '0.092790';
 
-use warnings;
-use strict;
 
-use parent qw/Catalyst::View/;
 
-our $VERSION = '0.04';
+use Moose;
+extends 'Catalyst::View';
 
 use JavaScript::Minifier::XS qw/minify/;
 use Path::Class::File;
 use URI;
 
-=head1 NAME
 
-Catalyst::View::JavaScript::Minifier::XS - Concenate and minify your JavaScript files.
+has stash_variable => (
+   is => 'ro',
+   isa => 'Str',
+   default => 'js',
+);
 
-=head1 VERSION
-
-Version 0.02
-
-=head1 SYNOPSIS
-
-    # creating MyApp::View::JavaScript
-    ./script/myapp_create.pl view JavaScript JavaScript::Minifier::XS
-
-	# in your controller file, as an action
-    sub js : Local {
-		my ( $self, $c ) = @_;
-
-		$c->stash->{js} = [qw/script1 script2/]; # loads root/js/script1.js and root/js/script2.js
-
-		$c->forward("View::JavaScript");
-    }
-
-	# in your html template use
-	<script type="text/javascript" src="/js"></script>
-
-=head1 DESCRIPTION
-
-Use your minified js files as a separated catalyst request. By default they are read from C<< $c->stash->{js} >> as array or string.
-
-=head1 CONFIG VARIABLES
-
-=over 2
-
-=item stash_variable
-
-sets a different stash variable from the default C<< $c->stash->{js} >>
-
-=item path
-
-sets a different path for your javascript files
-
-default : js
-
-=item subinclude
-
-setting this to true will take your js files (stash variable) from your referer action
-
-	# in your controller
-	sub action : Local {
-		my ( $self, $c ) = @_;
-
-		$c->stash->{js} = "exclusive"; # loads exclusive.js only when /action is loaded
-	}
-
-This could be very dangerous since it's using C<< $c->forward($c->request->headers->referer) >>. It doesn't work with the index action!
-
-default : false
-
-=back
-
-=cut
-
-__PACKAGE__->mk_accessors(qw(stash_variable path subinclude));
-
-__PACKAGE__->config(stash_variable => 'js', path => 'js', subinclude => 0);
+has path => (
+   is => 'ro',
+   isa => 'Str',
+   default => 'js',
+);
 
+has subinclude => (
+   is => 'ro',
+   isa => 'Bool',
+   default => undef,
+);
 
 sub process {
 	my ($self,$c) = @_;
@@ -151,9 +102,78 @@ sub process {
 	}
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=head1 VERSION
+
+version 0.092790
+
+=head1 NAME
+
+Catalyst::View::JavaScript::Minifier::XS - Concenate and minify your JavaScript files.
+
+=head1 SYNOPSIS
+
+    # creating MyApp::View::JavaScript
+    ./script/myapp_create.pl view JavaScript JavaScript::Minifier::XS
+
+	# in your controller file, as an action
+    sub js : Local {
+		my ( $self, $c ) = @_;
+
+		$c->stash->{js} = [qw/script1 script2/]; # loads root/js/script1.js and root/js/script2.js
+
+		$c->forward("View::JavaScript");
+    }
+
+	# in your html template use
+	<script type="text/javascript" src="/js"></script>
+
+=head1 DESCRIPTION
+
+Use your minified js files as a separated catalyst request. By default they are read from C<< $c->stash->{js} >> as array or string.
+
+=head1 CONFIG VARIABLES
+
+=over 2
+
+=item stash_variable
+
+sets a different stash variable from the default C<< $c->stash->{js} >>
+
+=item path
+
+sets a different path for your javascript files
+
+default : js
+
+=item subinclude
+
+setting this to true will take your js files (stash variable) from your referer action
+
+	# in your controller
+	sub action : Local {
+		my ( $self, $c ) = @_;
+
+		$c->stash->{js} = "exclusive"; # loads exclusive.js only when /action is loaded
+	}
+
+This could be very dangerous since it's using C<< $c->forward($c->request->headers->referer) >>. It doesn't work with the index action!
+
+default : false
+
+=back 
+
+
+
 =head1 SEE ALSO
 
-L<Catalyst> , L<Catalyst::View>, L<JavaScript::Minifier::XS>
+L<Catalyst>, L<Catalyst::View>, L<JavaScript::Minifier::XS>
 
 =head1 AUTHOR
 
@@ -167,13 +187,15 @@ Please report any bugs or feature requests to C<bug-catalyst-view-JavaScript-min
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Catalyst-View-JavaScript-Minifier-XS>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-=head1 COPYRIGHT & LICENSE
 
-Copyright 2009 Ivan Drinchev, all rights reserved.
 
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Ivan Drinchev <drinchev@gmail.com>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut 
 
-=cut
 
-1; # End of Catalyst::View::JavaScript::Minifier::XS
